var prefs = [];
async function openNewTab() {
  let tabs = await browser.tabs.query({
    active: true,
    currentWindow: true
  });

  let active = prefs["openInActive"];
  if (tabs.length > 0 && tabs[0].mailTab) {
    let msgs = await browser.mailTabs.getSelectedMessages(tabs[0].id);
    
    for (let i = 0; i < msgs.messages.length; i++) {
      browser.messageDisplay.open({
        active: active,
        headerMessageId: msgs.messages[i].messageHeaderId,
        location: "tab",
        messageId: msgs.messages[i].id
      });
    }
  }
}

async function init() {
  let result = await browser.storage.local.get("openInActive");
  prefs["openInActive"] = result.openInActive ? true : false;

  browser.storage.onChanged.addListener((changes, area) => {
    for (let item in changes) {
      prefs[item] = changes[item].newValue;
    }
  });

  browser.browserAction.onClicked.addListener(() => {
    openNewTab();
  });

  browser.messageDisplayAction.onClicked.addListener(() => {
    openNewTab();
  });

  let menuStr = await browser.i18n.getMessage("ntbMenuOpenLink");
  browser.menus.create({
    contexts: ["link"],
    id: "ntb_openlink",
    title: menuStr,
    targetUrlPatterns: ["*://*/*"],
    onclick: (info, tab) => {
      browser.tabs.create({
        active: prefs["openInActive"],
        url: info.linkUrl
      });
    }
  });
}

init();
